from .DataApiQuery import DataApiQuery, SamplingPeriod, REQUEST_LIMIT
from pydantic import ConfigDict, model_validator

"""This class inherits all the fields and validation on DataApiQuery and adds
the fields input_sampling_period and output_sampling_period."""


class FilterApiQuery(DataApiQuery):
    model_config = ConfigDict(extra="forbid")

    input_sampling_period: SamplingPeriod = SamplingPeriod.SECOND
    output_sampling_period: SamplingPeriod = SamplingPeriod.MINUTE

    @model_validator(mode="after")
    def validate_sample_size(self):
        # Calculate the number of samples based on the input sampling period
        samples = int(
            len(self.elements)
            * (self.endtime - self.starttime)
            / self.input_sampling_period
        )

        # Validate the request size
        if samples > REQUEST_LIMIT:
            raise ValueError(f"Request exceeds limit ({samples} > {REQUEST_LIMIT})")

        return self
